import { IDB2Session } from "../rest/session/doc/IDB2Session";
import { IDB2Column } from "./doc/IDB2Column";
/**
 * Class to handle exporting of DB2 tables
 * @export
 * @class ExportTable
 */
export declare abstract class ExportTable {
    /**
     * The database name
     * @type {string}
     * @memberof ExportTable
     * @private
     */
    protected readonly mDatabase: string;
    /**
     * The table name
     * @type {string}
     * @memberof ExportTable
     * @private
     */
    protected readonly mTable: string;
    /**
     * The table metadata
     * @type {IDB2Column[]|null}
     * @memberof ExportTable
     * @private
     */
    protected mMetadata: IDB2Column[] | null;
    /**
     * Connection to a DB2 region
     * @type {ibmdb.Database}
     * @memberof ExportTable
     * @private
     */
    private mConnection;
    /**
     * The connection string to use with the ODBC driver
     * @type {string}
     * @memberof ExportTable
     * @private
     */
    private readonly mConnectionString;
    /**
     * Constructor
     * @param {IDB2Session} session DB2 session parameters
     * @param {string} databaseName Name of the database
     * @param {string} tableName Name of the table
     */
    constructor(session: IDB2Session, databaseName: string, tableName: string);
    init(): Promise<void>;
    /**
     * Get a table metadata
     * @returns {Promise<IDB2Column[]>}
     * @memberof ExportTable
     */
    getTableMeta(): Promise<IDB2Column[]>;
    getColumnMeta(columnName: string): IDB2Column;
    /**
     * Supply data from table by one row
     * @returns {IterableIterator<any>}
     */
    rows(): IterableIterator<any>;
    /**
     * Extract a list of columns out of a table metadata
     * @returns {string[]} Columns list
     */
    getColumnNames(): string[];
    abstract export(): any;
}
