"use strict";
/*
* This program and the accompanying materials are made available under the terms of the *
* Eclipse Public License v2.0 which accompanies this distribution, and is available at *
* https://www.eclipse.org/legal/epl-v20.html                                      *
*                                                                                 *
* SPDX-License-Identifier: EPL-2.0                                                *
*                                                                                 *
* Copyright Contributors to the Zowe Project.                                     *
*                                                                                 *
*/
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.CicsBaseHandler = void 0;
const CicsSession_1 = require("./CicsSession");
/**
 * This class is used by the various cics handlers as the base class for their implementation.
 * All handlers should extend this class whenever possible
 */
class CicsBaseHandler {
    /**
     * This will grab the cics profile and create a session before calling the subclass
     * {@link CicsBaseHandler#processWithSession} method.
     *
     * @param {IHandlerParameters} commandParameters Command parameters sent by imperative.
     *
     * @returns {Promise<void>}
     */
    process(commandParameters) {
        return __awaiter(this, void 0, void 0, function* () {
            const profile = commandParameters.profiles.get("cics", false) || {};
            const session = CicsSession_1.CicsSession.createBasicCicsSessionFromArguments(commandParameters.arguments);
            const response = yield this.processWithSession(commandParameters, session, profile);
            commandParameters.response.progress.endBar(); // end any progress bars
            // Return as an object when using --response-format-json
            commandParameters.response.data.setObj(response);
        });
    }
}
exports.CicsBaseHandler = CicsBaseHandler;
//# sourceMappingURL=CicsBaseHandler.js.map