"use strict";
/*
 * This program and the accompanying materials are made available under the terms of the
 * Eclipse Public License v2.0 which accompanies this distribution, and is available at
 * https://www.eclipse.org/legal/epl-v20.html
 *
 * SPDX-License-Identifier: EPL-2.0
 *
 * Copyright Contributors to the Zowe Project.
 *
 */
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const cli_1 = require("@zowe/cli");
const imperative_1 = require("@zowe/imperative");
const FTPBase_Handler_1 = require("../../../FTPBase.Handler");
const api_1 = require("../../../api");
class ViewAllSpoolByJobIdHandler extends FTPBase_Handler_1.FTPBaseHandler {
    processFTP(params) {
        return __awaiter(this, void 0, void 0, function* () {
            this.log.debug("Downloading all spool files for job id: " + params.arguments.jobid);
            const destination = params.arguments.directory == null ? "./output/" : params.arguments.directory;
            const jobDetails = (yield api_1.JobUtils.findJobByID(params.connection, params.arguments.jobid));
            if (jobDetails.spoolFiles == null || jobDetails.spoolFiles.length === 0) {
                throw new imperative_1.ImperativeError({
                    msg: imperative_1.TextUtils.formatMessage("No spool files were available for job %s(%s). " +
                        "Try again after waiting a moment if the job is not yet in OUTPUT status.", jobDetails.jobname, jobDetails.jobid)
                });
            }
            const fullSpoolFiles = yield api_1.JobUtils.getSpoolFiles(params.connection, jobDetails.jobid);
            for (const spoolFileToDownload of fullSpoolFiles) {
                const mockJobFile = {
                    "jobid": jobDetails.jobid, "jobname": jobDetails.jobname,
                    "recfm": "FB", "lrecl": 80, "byte-count": spoolFileToDownload.byteCount,
                    // todo is recfm or lrecl available? FB 80 could be wrong
                    "record-count": 0,
                    "job-correlator": "",
                    "class": "A", "ddname": spoolFileToDownload.ddname,
                    "id": parseInt(spoolFileToDownload.id, 10),
                    "records-url": "",
                    "subsystem": "JES2",
                    "stepname": spoolFileToDownload.stepname,
                    "procstep": spoolFileToDownload.procstep === "N/A" || spoolFileToDownload.procstep == null ?
                        undefined : spoolFileToDownload.procstep,
                };
                const destinationFile = cli_1.DownloadJobs.getSpoolDownloadFile(mockJobFile, params.arguments.omitJobidDirectory, params.arguments.directory);
                this.log.info("Downloading spool file %s to local file %s", spoolFileToDownload.ddname, destinationFile);
                imperative_1.IO.createDirsSyncFromFilePath(destinationFile);
                imperative_1.IO.writeFile(destinationFile, spoolFileToDownload.contents);
            }
            const successMessage = params.response.console.log("Successfully downloaded %d spool files to %s", fullSpoolFiles.length, destination);
            params.response.data.setMessage(successMessage);
            this.log.info(successMessage);
        });
    }
}
exports.default = ViewAllSpoolByJobIdHandler;
//# sourceMappingURL=AllSpoolByJobId.Handler.js.map