import { IHandlerParameters } from "@zowe/imperative";
export default class BaseScsHandler {
    /**
     * Update profiles to be secure, or revert them to plain text
     * @param params Command handler parameters
     * @param shouldBeSecure Specifies whether credentials should be secure
     * @returns False if secure credential manager is not enabled
     */
    static updateProfiles(params: IHandlerParameters, shouldBeSecure: boolean): Promise<boolean>;
    /**
     * Check that CredentialManager is set in Imperative settings. If it is not,
     * throw an error.
     * @throws {Error}
     */
    private static ensureCredMgrIsEnabled;
    /**
     * Check if a profile is already secure. We assume it is secure, if it
     * contains a property whose value starts with the string "managed by" and
     * is marked as secure in the profile schema.
     * @param pd Profile data object
     * @returns True if the profile is already secure
     */
    private static isProfileSecure;
    /**
     * Revert a secure profile to be stored in plain text.
     * @param pd Profile data object
     * @returns String to be logged to the console
     */
    private static makeProfileInsecure;
    /**
     * Update a plain text profile to be stored securely.
     * @param pd Profile data object
     * @returns String to be logged to the console
     */
    private static makeProfileSecure;
}
